@@ -1,13 +1,20 @@
 from .pysdbots import *
 
+__version__ = "0.1.1"
+
+
 __all__ = [
-    "hirunews",
-    "fakeinfo",
-    "ipinfo",
-    "lyrics",
-    "sk_checker",
+    "anime_logo",
+    "tiktok",
+    "apod",
+    "detect_lang",
     "write",
+    "chk",
+    "sk_checker",
+    "lyrics",
+    "ipinfo",
+    "hirunews",
     "logohq",
-    "detect_lang"
+    "fakeinfo",
 ]
 
